pub struct Attachment {
pub create_time: Option<DateTime<Utc>>,
pub creator: Option<Actor>,
pub filename: Option<String>,
pub mime_type: Option<String>,
pub name: Option<String>,
pub size_bytes: Option<i64>,
}Expand description
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself. That being said, the name of an Attachment object can be used to download its accompanying file through the media.download endpoint. While attachments can be uploaded in the console at the same time as a comment, they’re associated on a “case” level, not a “comment” level.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- attachments get cases (response)
- upload media (response)
Fields
create_time: Option<DateTime<Utc>>Output only. The time at which the attachment was created.
creator: Option<Actor>Output only. The user who uploaded the attachment. Note, the name and email will be obfuscated if the attachment was uploaded by Google support.
filename: Option<String>The filename of the attachment (e.g. "graph.jpg").
mime_type: Option<String>Output only. The MIME type of the attachment (e.g. text/plain).
name: Option<String>Output only. Identifier. The resource name of the attachment.
size_bytes: Option<i64>Output only. The size of the attachment in bytes.