Struct google_cloudsupport2_beta::api::Comment
source · pub struct Comment {
pub body: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub creator: Option<Actor>,
pub name: Option<String>,
pub plain_text_body: Option<String>,
}Expand description
Case comments are the main way Google Support communicates with a user who has opened a case. When a user responds to Google Support, the user’s responses also appear as comments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- comments create cases (request|response)
Fields
body: Option<String>The full comment body. Maximum of 12800 characters. This can contain rich text syntax.
create_time: Option<DateTime<Utc>>Output only. The time when this comment was created.
creator: Option<Actor>Output only. The user or Google Support agent created this comment.
name: Option<String>Output only. The resource name for the comment.
plain_text_body: Option<String>Output only. DEPRECATED. An automatically generated plain text version of body with all rich text syntax stripped.