pub struct Escalation {
pub justification: Option<String>,
pub reason: Option<String>,
}Expand description
An escalation of a support case.
This type is not used in any activity, and only used as part of another schema.
Fields
justification: Option<String>Required. A free text description to accompany the reason field above. Provides additional context on why the case is being escalated.
reason: Option<String>Required. The reason why the Case is being escalated.