Struct google_cloudsupport2_beta::api::Product
source · pub struct Product {
pub product_line: Option<String>,
pub product_subline: Option<String>,
}Expand description
The full product a case may be associated with, including Product Line and Product Subline.
This type is not used in any activity, and only used as part of another schema.
Fields
product_line: Option<String>The Product Line of the Product.
product_subline: Option<String>The Product Subline of the Product, such as “Maps Billing”.